=======
statopy
=======

Statistics and Probability processing

Description
===========

Code for scalar and vector running (online) statistics and linear regression, CDF/PDF estimation from data.

`Class descriptions <http://htmlpreview.github.io/?https://github.com/mmiguel6288code/statopy/blob/master/docs/statopy/statopy.html>`_

Note
====

This project has been set up using PyScaffold 3.3. For details and usage
information on PyScaffold see https://pyscaffold.org/.
